#-*-coding:Utf-8 -*-
# script to build Evaluator objects and save them in files

from __future__ import print_function

import evaltools as evt
import os
from datetime import date

#################
# define params #
#################

startDate = date(2018, 11, 19)
endDate = date(2018, 11, 23)
liste_pol = ['PM10']
models_list = ['mod1', 'mod2']


model_colors = {'mod1': 'lime',
                'mod2': 'red',
                'mod3': 'chocolate'}

# Factor to apply to original values, to convert to target units
correc_units = {'PM25': 1.,
                'PM10': 1.,
                'O3': 1.,
                'NO2': 1.}

#################
# read listings #
#################

sim_path = "./sim/"       # generic path to netcdf files, simulation data
outpath = "./dump_files/"  # output directory
if not os.path.exists(outpath):
    os.makedirs(outpath)


for polluant in liste_pol:
    correc_unit = correc_units.get(polluant, 1.)

    # paths to ASCII files, observation data and stations list
    obs_path = "./obs/{station}.{year}.dat"
    listing_path = "./stations." + polluant

    print("\nImporting stations for ~~~ "+polluant+" ~~~")
    stations = evt.utils.read_listing(listing_path)

    print("\ncreating Observations object ...")
    observations = evt.evaluator.Observations.fromTimeSeries(
                                        generic_file_path=obs_path,
                                        species=polluant,
                                        start=startDate, end=endDate,
                                        stations=stations,
                                        forecastHorizon=1)
    print(observations.dataset.data.head())

    for model in models_list:
        print("\ncreating Simulations object for "+model+" ...")

        # complementary path to simulation files
        path = sim_path + model + ".2018." + polluant + ".nc"
        print("file path : " + path)

        simulations = evt.netcdf.Simulations_fromNetCDF(
                                          generic_file_path=path,
                                          stations=stations,
                                          species=polluant,
                                          start=startDate, end=endDate,
                                          forecastHorizon=1,
                                          model=model,
                                          correc_unit=correc_unit,
                                          availability_ratio=0.25,
                                          level=0, times_name='Times',
                                          date_format="%Y-%m-%d_%H:00:00")
        print(simulations.datasets[0].data.head())

        # create Evaluator object based on observations and simulations objects
        evt1 = evt.evaluator.Evaluator(observations,
                                       simulations,
                                       color=model_colors.get(model))

        # save Evaluator object, for later use
        evt1.dump(outpath + polluant + "_" + model + "_2018.evt")
        print(evt1.summary())
